pub fn parse_source(url: &Url, string: &str) -> (Option<Turtle>, Vec<String>)Expand description
Compatibility shim for conformance tests and other callers expecting the old parse_source API.
Returns (Some(Turtle), errors) — the new parser always recovers so Turtle is always Some.