pub async fn find(
location: &str,
fs: &Fs,
client: &impl Client,
) -> Option<Vec<(String, Url)>>Expand description
Finds a resource. If the location starts with http, it is a remote resource. If the location fails to parse as a url, it is a file path to read.